# Quantreo 

Quantreo is a Python library to streamline feature engineering, target engineering, and soon much more, for quantitative trading strategies. Built for traders and quants, Quantreo helps you create high-value signals and targets for your machine learning models.

- 🔗 **Documentation**: [https://www.quantreo.com/docs](https://www.quantreo.com/docs)
- 💻 **Repository**: [https://github.com/Quantreo/quantreo](https://github.com/Quantreo/quantreo)

## Install Quantreo
```bash
pip install quantreo
```


## Why use Quantreo?

- Save time with ready-to-use trading features (volatility, trend, candle patterns, market regimes).
- Speed up your pipeline with fast, Numba-accelerated computations.
- Integrates easily with your machine learning models.

---

Feel free to reach out at **lucas@quantreo.com**.

## License
MIT © Lucas Inglese, 2025
